@@ -36,6 +36,7 @@ from abc import ABC
 from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, Set, Tuple, Union, cast, overload
 
 # 3rd party
+import dist_meta
 import dom_toml
 from domdf_python_tools.compat import importlib_metadata
 from domdf_python_tools.doctools import prettify_docstrings
@@ -92,7 +93,7 @@ class ComparableRequirement(Requirement):
 					return False
 		return True
 
-	def __eq__(self, other) -> bool:
+	def __eq__(self, other) -> bool:  # noqa: MAN001
 
 		if isinstance(other, str):
 			try:
@@ -113,7 +114,7 @@ class ComparableRequirement(Requirement):
 		else:  # pragma: no cover
 			return NotImplemented
 
-	def __lt__(self, other) -> bool:
+	def __lt__(self, other) -> bool:  # noqa: MAN001
 		if isinstance(other, Requirement):
 			if self.name != other.name:
 				return self.name < other.name
@@ -128,21 +129,21 @@ class ComparableRequirement(Requirement):
 		else:  # pragma: no cover
 			return NotImplemented
 
-	def __le__(self, other) -> bool:
+	def __le__(self, other) -> bool:  # noqa: MAN001
 		if not isinstance(other, (Requirement, str)):  # pragma: no cover
 			return NotImplemented
 		if self < other or self == other:
 			return True
 		return False
 
-	def __ge__(self, other) -> bool:
+	def __ge__(self, other) -> bool:  # noqa: MAN001
 		if not isinstance(other, (Requirement, str)):  # pragma: no cover
 			return NotImplemented
 		if self > other or self == other:
 			return True
 		return False
 
-	def __gt__(self, other) -> bool:
+	def __gt__(self, other) -> bool:  # noqa: MAN001
 		if isinstance(other, Requirement):
 			if self.name != other.name:
 				return self.name > other.name
@@ -604,10 +605,12 @@ def list_requirements(name: str, depth: int = 1) -> Iterator[Union[str, List[str
 	req = ComparableRequirement(name)
 
 	try:
-		raw_deps = importlib_metadata.requires(req.name) or []
-	except importlib_metadata.PackageNotFoundError:
+		distro = dist_meta.distributions.get_distribution(req.name)
+	except dist_meta.distributions.DistributionNotFoundError:
 		return
 
+	raw_deps = distro.get_metadata().get_all("Requires-Dist") or []
+
 	for requirement in [ComparableRequirement(r) for r in sorted(raw_deps)]:
 		if requirement.marker:
 			if req.extras:
@@ -743,7 +746,7 @@ def parse_pyproject_extras(
 			}
 
 
-def _denormalize_ruamel(req: Requirement):
+def _denormalize_ruamel(req: Requirement) -> None:
 	if req.name in {"ruamel-yaml", "ruamel_yaml"}:
 		# Special case to work around issue with Poetry
 		req.name = "ruamel.yaml"
